@@ -14,43 +14,42 @@
  * limitations under the License.
  *
 */
-
-#ifdef _WIN32
-#pragma warning(push)
-#pragma warning(disable: 4005)
-#pragma warning(disable: 4251)
+#if defined(_MSC_VER)
+  #pragma warning(push)
+  #pragma warning(disable: 4005)
+  #pragma warning(disable: 4251)
 #endif
-#include <ignition/msgs/pointcloud_packed.pb.h>
-#ifdef _WIN32
-#pragma warning(pop)
+#include <gz/msgs/pointcloud_packed.pb.h>
+#if defined(_MSC_VER)
+  #pragma warning(pop)
 #endif
 
-#include <ignition/common/Console.hh>
-#include <ignition/common/Profiler.hh>
-#include <ignition/msgs/Utility.hh>
-#include <ignition/transport/Node.hh>
+#include <gz/common/Console.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/msgs/Utility.hh>
+#include <gz/transport/Node.hh>
 
-#include "ignition/sensors/GpuLidarSensor.hh"
-#include "ignition/sensors/SensorFactory.hh"
+#include "gz/sensors/GpuLidarSensor.hh"
+#include "gz/sensors/SensorFactory.hh"
 
-using namespace ignition::sensors;
+using namespace gz::sensors;
 
 /// \brief Private data for the GpuLidar class
-class ignition::sensors::GpuLidarSensorPrivate
+class gz::sensors::GpuLidarSensorPrivate
 {
   /// \brief Fill the point cloud packed message
   /// \param[in] _laserBuffer Lidar data buffer.
   public: void FillPointCloudMsg(const float *_laserBuffer);
 
   /// \brief Rendering camera
-  public: ignition::rendering::GpuRaysPtr gpuRays;
+  public: gz::rendering::GpuRaysPtr gpuRays;
 
   /// \brief Connection to the Manager's scene change event.
-  public: ignition::common::ConnectionPtr sceneChangeConnection;
+  public: gz::common::ConnectionPtr sceneChangeConnection;
 
   /// \brief Event that is used to trigger callbacks when a new
   /// lidar frame is available
-  public: ignition::common::EventT<
+  public: gz::common::EventT<
           void(const float *_scan, unsigned int _width,
                unsigned int _height, unsigned int _channels,
                const std::string &_format)> lidarEvent;
@@ -61,7 +60,7 @@ class ignition::sensors::GpuLidarSensorPrivate
                const std::string &_format);
 
   /// \brief Connection to gpuRays new lidar frame event
-  public: ignition::common::ConnectionPtr lidarFrameConnection;
+  public: gz::common::ConnectionPtr lidarFrameConnection;
 
   /// \brief The point cloud message.
   public: msgs::PointCloudPacked pointMsg;
@@ -94,7 +93,7 @@ GpuLidarSensor::~GpuLidarSensor()
 }
 
 /////////////////////////////////////////////////
-void GpuLidarSensor::SetScene(ignition::rendering::ScenePtr _scene)
+void GpuLidarSensor::SetScene(gz::rendering::ScenePtr _scene)
 {
   std::lock_guard<std::mutex> lock(this->lidarMutex);
   // APIs make it possible for the scene pointer to change
@@ -110,7 +109,7 @@ void GpuLidarSensor::SetScene(ignition::rendering::ScenePtr _scene)
 
 //////////////////////////////////////////////////
 void GpuLidarSensor::RemoveGpuRays(
-    ignition::rendering::ScenePtr _scene)
+    gz::rendering::ScenePtr _scene)
 {
   if (_scene)
   {
@@ -151,7 +150,7 @@ bool GpuLidarSensor::Load(const sdf::Sensor &_sdf)
   this->SetTopic(this->Topic() + "/points");
 
   this->dataPtr->pointPub =
-      this->dataPtr->node.Advertise<ignition::msgs::PointCloudPacked>(
+      this->dataPtr->node.Advertise<gz::msgs::PointCloudPacked>(
           this->Topic());
 
   if (!this->dataPtr->pointPub)
@@ -314,7 +313,7 @@ bool GpuLidarSensor::Update(const std::chrono::steady_clock::duration &_now)
 }
 
 /////////////////////////////////////////////////
-ignition::common::ConnectionPtr GpuLidarSensor::ConnectNewLidarFrame(
+gz::common::ConnectionPtr GpuLidarSensor::ConnectNewLidarFrame(
           std::function<void(const float *_scan, unsigned int _width,
                   unsigned int _height, unsigned int _channels,
                   const std::string &/*_format*/)> _subscriber)
@@ -323,7 +322,7 @@ ignition::common::ConnectionPtr GpuLidarSensor::ConnectNewLidarFrame(
 }
 
 /////////////////////////////////////////////////
-ignition::rendering::GpuRaysPtr GpuLidarSensor::GpuRays() const
+gz::rendering::GpuRaysPtr GpuLidarSensor::GpuRays() const
 {
   return this->dataPtr->gpuRays;
 }
@@ -335,13 +334,13 @@ bool GpuLidarSensor::IsHorizontal() const
 }
 
 //////////////////////////////////////////////////
-ignition::math::Angle GpuLidarSensor::HFOV() const
+gz::math::Angle GpuLidarSensor::HFOV() const
 {
   return this->dataPtr->gpuRays->HFOV();
 }
 
 //////////////////////////////////////////////////
-ignition::math::Angle GpuLidarSensor::VFOV() const
+gz::math::Angle GpuLidarSensor::VFOV() const
 {
   return this->dataPtr->gpuRays->VFOV();
 }
