@@ -14,22 +14,32 @@
  * limitations under the License.
  *
 */
-#include <ignition/common/Console.hh>
-#include <ignition/common/Event.hh>
-#include <ignition/common/Profiler.hh>
-#include <ignition/transport/Node.hh>
+#if defined(_MSC_VER)
+  #pragma warning(push)
+  #pragma warning(disable: 4005)
+  #pragma warning(disable: 4251)
+#endif
+#include <gz/msgs/laserscan.pb.h>
+#if defined(_MSC_VER)
+  #pragma warning(pop)
+#endif
+
+#include <gz/common/Console.hh>
+#include <gz/common/Event.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/transport/Node.hh>
 #include <sdf/Lidar.hh>
 
-#include "ignition/sensors/GaussianNoiseModel.hh"
-#include "ignition/sensors/Lidar.hh"
-#include "ignition/sensors/Noise.hh"
-#include "ignition/sensors/SensorFactory.hh"
-#include "ignition/sensors/SensorTypes.hh"
+#include "gz/sensors/GaussianNoiseModel.hh"
+#include "gz/sensors/Lidar.hh"
+#include "gz/sensors/Noise.hh"
+#include "gz/sensors/SensorFactory.hh"
+#include "gz/sensors/SensorTypes.hh"
 
-using namespace ignition::sensors;
+using namespace gz::sensors;
 
 /// \brief Private data for Lidar class
-class ignition::sensors::LidarPrivate
+class gz::sensors::LidarPrivate
 {
   /// \brief node to create publisher
   public: transport::Node node;
@@ -38,7 +48,7 @@ class ignition::sensors::LidarPrivate
   public: transport::Node::Publisher pub;
 
   /// \brief Laser message to publish data.
-  public: ignition::msgs::LaserScan laserMsg;
+  public: gz::msgs::LaserScan laserMsg;
 
   /// \brief Noise added to sensor data
   public: std::map<SensorNoiseType, NoisePtr> noises;
@@ -110,7 +120,7 @@ bool Lidar::Load(const sdf::Sensor &_sdf)
     this->SetTopic("/lidar");
 
   this->dataPtr->pub =
-      this->dataPtr->node.Advertise<ignition::msgs::LaserScan>(
+      this->dataPtr->node.Advertise<gz::msgs::LaserScan>(
         this->Topic());
   if (!this->dataPtr->pub)
   {
@@ -179,7 +189,7 @@ bool Lidar::Load(sdf::ElementPtr _sdf)
 }
 
 /////////////////////////////////////////////////
-ignition::common::ConnectionPtr Lidar::ConnectNewLidarFrame(
+gz::common::ConnectionPtr Lidar::ConnectNewLidarFrame(
           std::function<void(const float *_scan, unsigned int _width,
                   unsigned int _heighti, unsigned int _channels,
                   const std::string &/*_format*/)> /*_subscriber*/)
@@ -208,7 +218,7 @@ void Lidar::ApplyNoise()
         range = this->dataPtr->noises[LIDAR_NOISE]->Apply(range);
         if (std::isfinite(range))
         {
-          range = ignition::math::clamp(range,
+          range = gz::math::clamp(range,
             this->RangeMin(), this->RangeMax());
         }
         this->laserBuffer[index*3] = range;
@@ -250,8 +260,8 @@ bool Lidar::PublishLidarScan(const std::chrono::steady_clock::duration &_now)
     this->dataPtr->laserMsg.clear_intensities();
     for (int i = 0; i < numRays; ++i)
     {
-      this->dataPtr->laserMsg.add_ranges(ignition::math::NAN_F);
-      this->dataPtr->laserMsg.add_intensities(ignition::math::NAN_F);
+      this->dataPtr->laserMsg.add_ranges(gz::math::NAN_F);
+      this->dataPtr->laserMsg.add_intensities(gz::math::NAN_F);
     }
   }
 
@@ -262,7 +272,7 @@ bool Lidar::PublishLidarScan(const std::chrono::steady_clock::duration &_now)
       int index = j * this->RangeCount() + i;
       double range = this->laserBuffer[index*3];
 
-      range = ignition::math::isnan(range) ? this->RangeMax() : range;
+      range = gz::math::isnan(range) ? this->RangeMax() : range;
       this->dataPtr->laserMsg.set_ranges(index, range);
       this->dataPtr->laserMsg.set_intensities(index,
           this->laserBuffer[index * 3 + 1]);
@@ -290,7 +300,7 @@ double Lidar::RangeCountRatio() const
 }
 
 //////////////////////////////////////////////////
-ignition::math::Angle Lidar::AngleMin() const
+gz::math::Angle Lidar::AngleMin() const
 {
   return this->dataPtr->sdfLidar.HorizontalScanMinAngle();
 }
@@ -302,7 +312,7 @@ void Lidar::SetAngleMin(double _angle)
 }
 
 //////////////////////////////////////////////////
-ignition::math::Angle Lidar::AngleMax() const
+gz::math::Angle Lidar::AngleMax() const
 {
   return this->dataPtr->sdfLidar.HorizontalScanMaxAngle();
 }
@@ -375,7 +385,7 @@ void Lidar::SetParent(const std::string &_parent)
 }
 
 //////////////////////////////////////////////////
-ignition::math::Angle Lidar::VerticalAngleMin() const
+gz::math::Angle Lidar::VerticalAngleMin() const
 {
   return this->dataPtr->sdfLidar.VerticalScanMinAngle();
 }
@@ -387,7 +397,7 @@ void Lidar::SetVerticalAngleMin(const double _angle)
 }
 
 //////////////////////////////////////////////////
-ignition::math::Angle Lidar::VerticalAngleMax() const
+gz::math::Angle Lidar::VerticalAngleMax() const
 {
   return this->dataPtr->sdfLidar.VerticalScanMaxAngle();
 }
