@@ -15,45 +15,24 @@
  *
 */
 
-#include "ignition/sensors/Manager.hh"
+#include "gz/sensors/Manager.hh"
 #include <memory>
 #include <unordered_map>
-#include <ignition/common/PluginLoader.hh>
-#include <ignition/common/Plugin.hh>
-#include <ignition/common/Profiler.hh>
-#include <ignition/common/SystemPaths.hh>
-#include <ignition/common/Console.hh>
+#include <gz/common/Profiler.hh>
+#include <gz/common/SystemPaths.hh>
+#include <gz/common/Console.hh>
 
-#include "ignition/sensors/config.hh"
-#include "ignition/sensors/SensorFactory.hh"
+#include "gz/sensors/config.hh"
+#include "gz/sensors/SensorFactory.hh"
 
-using namespace ignition::sensors;
+using namespace gz::sensors;
 
-class ignition::sensors::ManagerPrivate
+class gz::sensors::ManagerPrivate
 {
-  /// \brief constructor
-  public: ManagerPrivate();
-
-  /// \brief destructor
-  public: ~ManagerPrivate();
-
   /// \brief Loaded sensors.
   public: std::map<SensorId, std::unique_ptr<Sensor>> sensors;
-
-  /// \brief Sensor factory for creating sensors from plugins;
-  public: SensorFactory sensorFactory;
 };
 
-//////////////////////////////////////////////////
-ManagerPrivate::ManagerPrivate()
-{
-}
-
-//////////////////////////////////////////////////
-ManagerPrivate::~ManagerPrivate()
-{
-}
-
 //////////////////////////////////////////////////
 Manager::Manager() :
   dataPtr(new ManagerPrivate)
@@ -72,31 +51,26 @@ bool Manager::Init()
 }
 
 //////////////////////////////////////////////////
-ignition::sensors::Sensor *Manager::Sensor(
-    ignition::sensors::SensorId _id)
+Sensor *Manager::Sensor(
+    SensorId _id)
 {
   auto iter = this->dataPtr->sensors.find(_id);
   return iter != this->dataPtr->sensors.end() ? iter->second.get() : nullptr;
 }
 
 //////////////////////////////////////////////////
-void Manager::AddPluginPaths(const std::string &_paths)
+void Manager::AddPluginPaths(const std::string &)
 {
-  this->dataPtr->sensorFactory.AddPluginPaths(_paths);
+  ignwarn << "Trying to add plugin paths, but Ignition Sensors doesn't support"
+          << " plugins anymore." << std::endl;
 }
 
 //////////////////////////////////////////////////
-bool Manager::Remove(const ignition::sensors::SensorId _id)
+bool Manager::Remove(const SensorId _id)
 {
   return this->dataPtr->sensors.erase(_id) > 0;
 }
 
-//////////////////////////////////////////////////
-void Manager::RunOnce(const ignition::common::Time &_time, bool _force)
-{
-  this->RunOnce(math::secNsecToDuration(_time.sec, _time.nsec), _force);
-}
-
 //////////////////////////////////////////////////
 void Manager::RunOnce(
   const std::chrono::steady_clock::duration &_time, bool _force)
@@ -109,25 +83,30 @@ void Manager::RunOnce(
 }
 
 /////////////////////////////////////////////////
-ignition::sensors::SensorId Manager::CreateSensor(const sdf::Sensor &_sdf)
+SensorId Manager::AddSensor(
+  std::unique_ptr<sensors::Sensor> _sensor)
 {
-  auto sensor = this->dataPtr->sensorFactory.CreateSensor(_sdf);
-  if (!sensor)
+  if (!_sensor)
     return NO_SENSOR;
-
-  SensorId id = sensor->Id();
-  this->dataPtr->sensors[id] = std::move(sensor);
+  SensorId id = _sensor->Id();
+  this->dataPtr->sensors[id] = std::move(_sensor);
   return id;
 }
 
 /////////////////////////////////////////////////
-ignition::sensors::SensorId Manager::CreateSensor(sdf::ElementPtr _sdf)
+SensorId Manager::CreateSensor(const sdf::Sensor &)
 {
-  auto sensor = this->dataPtr->sensorFactory.CreateSensor(_sdf);
-  if (!sensor)
-    return NO_SENSOR;
+  ignwarn << "Trying to create sensor without providing sensor type. Ignition"
+          << " Sensor doesn't support sensor registration anymore. Use the"
+          << " templated `CreateSensor` function instead." << std::endl;
+  return NO_SENSOR;
+}
 
-  SensorId id = sensor->Id();
-  this->dataPtr->sensors[id] = std::move(sensor);
-  return id;
+/////////////////////////////////////////////////
+SensorId Manager::CreateSensor(sdf::ElementPtr)
+{
+  ignwarn << "Trying to create sensor without providing sensor type. Ignition"
+          << " Sensor doesn't support sensor registration anymore. Use the"
+          << " templated `CreateSensor` function instead." << std::endl;
+  return NO_SENSOR;
 }
