@@ -22,16 +22,17 @@
 #pragma warning(disable: 4005)
 #pragma warning(disable: 4251)
 #endif
-#include <ignition/msgs/camera_info.pb.h>
+#include <gz/msgs/camera_info.pb.h>
 #include <ignition/msgs.hh>
 #ifdef _WIN32
 #pragma warning(pop)
 #endif
 
-#include <ignition/common/Filesystem.hh>
-#include <ignition/common/Event.hh>
-#include <ignition/sensors/Manager.hh>
-#include <ignition/sensors/ThermalCameraSensor.hh>
+#include <gz/common/Filesystem.hh>
+#include <gz/common/Event.hh>
+#include <gz/sensors/Manager.hh>
+#include <gz/sensors/ThermalCameraSensor.hh>
+#include <gz/utils/ExtraTestMacros.hh>
 
 // TODO(louise) Remove these pragmas once ign-rendering is disabling the
 // warnings
@@ -39,10 +40,10 @@
 #pragma warning(push)
 #pragma warning(disable: 4251)
 #endif
-#include <ignition/rendering/RenderEngine.hh>
-#include <ignition/rendering/RenderingIface.hh>
-#include <ignition/rendering/Scene.hh>
-#include <ignition/rendering/Visual.hh>
+#include <gz/rendering/RenderEngine.hh>
+#include <gz/rendering/RenderingIface.hh>
+#include <gz/rendering/Scene.hh>
+#include <gz/rendering/Visual.hh>
 #ifdef _WIN32
 #pragma warning(pop)
 #endif
@@ -59,9 +60,9 @@ unsigned char *g_thermalBuffer8Bit = nullptr;
 
 std::mutex g_infoMutex;
 unsigned int g_infoCounter = 0;
-ignition::msgs::CameraInfo g_infoMsg;
+gz::msgs::CameraInfo g_infoMsg;
 
-void OnCameraInfo(const ignition::msgs::CameraInfo & _msg)
+void OnCameraInfo(const gz::msgs::CameraInfo & _msg)
 {
   g_infoMutex.lock();
   g_infoCounter++;
@@ -69,7 +70,7 @@ void OnCameraInfo(const ignition::msgs::CameraInfo & _msg)
   g_infoMutex.unlock();
 }
 
-void OnImage(const ignition::msgs::Image &_msg)
+void OnImage(const gz::msgs::Image &_msg)
 {
   g_mutex.lock();
   unsigned int thermalSamples = _msg.width() * _msg.height();
@@ -81,7 +82,7 @@ void OnImage(const ignition::msgs::Image &_msg)
   g_mutex.unlock();
 }
 
-void OnImage8Bit(const ignition::msgs::Image &_msg)
+void OnImage8Bit(const gz::msgs::Image &_msg)
 {
   g_mutex.lock();
   unsigned int thermalSamples = _msg.width() * _msg.height();
@@ -107,7 +108,7 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
     const std::string &_renderEngine)
 {
   // get the darn test data
-  std::string path = ignition::common::joinPaths(PROJECT_SOURCE_PATH, "test",
+  std::string path = gz::common::joinPaths(PROJECT_SOURCE_PATH, "test",
       "sdf", "thermal_camera_sensor_builtin.sdf");
   sdf::SDFPtr doc(new sdf::SDF());
   sdf::init(doc);
@@ -132,7 +133,7 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
   double near_ = clipPtr->Get<double>("near");
 
   double unitBoxSize = 1.0;
-  ignition::math::Vector3d boxPosition(3.0, 0.0, 0.0);
+  gz::math::Vector3d boxPosition(3.0, 0.0, 0.0);
 
   // If ogre is not the engine, don't run the test
   if ((_renderEngine.compare("ogre") != 0) &&
@@ -144,7 +145,7 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
   }
 
   // Setup ign-rendering with an empty scene
-  auto *engine = ignition::rendering::engine(_renderEngine);
+  auto *engine = gz::rendering::engine(_renderEngine);
   if (!engine)
   {
     igndbg << "Engine '" << _renderEngine
@@ -152,14 +153,14 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
     return;
   }
 
-  ignition::rendering::ScenePtr scene = engine->CreateScene("scene");
+  gz::rendering::ScenePtr scene = engine->CreateScene("scene");
 
   // Create an scene with a box in it
   scene->SetAmbientLight(0.3, 0.3, 0.3);
-  ignition::rendering::VisualPtr root = scene->RootVisual();
+  gz::rendering::VisualPtr root = scene->RootVisual();
 
   // create box visual
-  ignition::rendering::VisualPtr box = scene->CreateVisual();
+  gz::rendering::VisualPtr box = scene->CreateVisual();
   box->AddGeometry(scene->CreateBox());
   box->SetOrigin(0.0, 0.0, 0.0);
   box->SetLocalPosition(boxPosition);
@@ -172,10 +173,10 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
 
   root->AddChild(box);
 
-  ignition::sensors::Manager mgr;
+  gz::sensors::Manager mgr;
 
-  ignition::sensors::ThermalCameraSensor *thermalSensor =
-      mgr.CreateSensor<ignition::sensors::ThermalCameraSensor>(sensorPtr);
+  gz::sensors::ThermalCameraSensor *thermalSensor =
+      mgr.CreateSensor<gz::sensors::ThermalCameraSensor>(sensorPtr);
   ASSERT_NE(thermalSensor, nullptr);
   EXPECT_FALSE(thermalSensor->HasConnections());
 
@@ -192,12 +193,12 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
 
   std::string topic =
     "/test/integration/ThermalCameraPlugin_imagesWithBuiltinSDF/image";
-  WaitForMessageTestHelper<ignition::msgs::Image> helper(topic);
+  WaitForMessageTestHelper<gz::msgs::Image> helper(topic);
   EXPECT_TRUE(thermalSensor->HasConnections());
 
   std::string infoTopic =
     "/test/integration/ThermalCameraPlugin_imagesWithBuiltinSDF/camera_info";
-  WaitForMessageTestHelper<ignition::msgs::CameraInfo> infoHelper(infoTopic);
+  WaitForMessageTestHelper<gz::msgs::CameraInfo> infoHelper(infoTopic);
 
   // Update once to create image
   mgr.RunOnce(std::chrono::steady_clock::duration::zero());
@@ -206,7 +207,7 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
   EXPECT_TRUE(infoHelper.WaitForMessage()) << infoHelper;
 
   // subscribe to the thermal camera topic
-  ignition::transport::Node node;
+  gz::transport::Node node;
   node.Subscribe(topic, &OnImage);
 
   // subscribe to the thermal camera topic
@@ -225,7 +226,7 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
       std::chrono::duration< double >(0.001));
   int counter = 0;
   int infoCounter = 0;
-  ignition::msgs::CameraInfo infoMsg;
+  gz::msgs::CameraInfo infoMsg;
   for (int sleep = 0;
        sleep < 300 && (counter == 0 || infoCounter == 0); ++sleep)
   {
@@ -271,7 +272,7 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
   ASSERT_EQ(1, infoMsg.header().data(0).value().size());
   EXPECT_EQ("camera1", infoMsg.header().data(0).value(0));
   EXPECT_TRUE(infoMsg.has_distortion());
-  EXPECT_EQ(ignition::msgs::CameraInfo::Distortion::PLUMB_BOB,
+  EXPECT_EQ(gz::msgs::CameraInfo::Distortion::PLUMB_BOB,
       infoMsg.distortion().model());
   EXPECT_EQ(5, infoMsg.distortion().k().size());
   EXPECT_TRUE(infoMsg.has_intrinsics());
@@ -281,11 +282,9 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
   EXPECT_EQ(9, infoMsg.rectification_matrix().size());
 
   // Check that for a box really close it returns box temperature
-  root->RemoveChild(box);
-  ignition::math::Vector3d boxPositionNear(
+  gz::math::Vector3d boxPositionNear(
       unitBoxSize * 0.5 + near_ * 0.5, 0.0, 0.0);
   box->SetLocalPosition(boxPositionNear);
-  root->AddChild(box);
 
   mgr.RunOnce(std::chrono::steady_clock::duration::zero(), true);
   for (int sleep = 0;
@@ -315,11 +314,9 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
   g_mutex.unlock();
 
   // Check that for a box really far it returns ambient temperature
-  root->RemoveChild(box);
-  ignition::math::Vector3d boxPositionFar(
+  gz::math::Vector3d boxPositionFar(
       unitBoxSize * 0.5 + far_ * 1.5, 0.0, 0.0);
   box->SetLocalPosition(boxPositionFar);
-  root->AddChild(box);
 
   mgr.RunOnce(std::chrono::steady_clock::duration::zero(), true);
   for (int sleep = 0;
@@ -351,13 +348,19 @@ void ThermalCameraSensorTest::ImagesWithBuiltinSDF(
   delete [] g_thermalBuffer;
   g_thermalBuffer = nullptr;
 
+  // Clean up rendering ptrs
+  box.reset();
+
   // Clean up
+  mgr.Remove(thermalSensor->Id());
   engine->DestroyScene(scene);
-  ignition::rendering::unloadEngine(engine->Name());
+  gz::rendering::unloadEngine(engine->Name());
 }
 
 //////////////////////////////////////////////////
-TEST_P(ThermalCameraSensorTest, ImagesWithBuiltinSDF)
+// See: https://github.com/gazebosim/gz-rendering/issues/654
+TEST_P(ThermalCameraSensorTest,
+       IGN_UTILS_TEST_DISABLED_ON_MAC(ImagesWithBuiltinSDF))
 {
   ImagesWithBuiltinSDF(GetParam());
 }
@@ -367,7 +370,7 @@ void ThermalCameraSensorTest::Images8BitWithBuiltinSDF(
     const std::string &_renderEngine)
 {
   // get the darn test data
-  std::string path = ignition::common::joinPaths(PROJECT_SOURCE_PATH, "test",
+  std::string path = gz::common::joinPaths(PROJECT_SOURCE_PATH, "test",
       "sdf", "thermal_camera_sensor_8bit_builtin.sdf");
   sdf::SDFPtr doc(new sdf::SDF());
   sdf::init(doc);
@@ -395,7 +398,7 @@ void ThermalCameraSensorTest::Images8BitWithBuiltinSDF(
   double near_ = clipPtr->Get<double>("near");
 
   double unitBoxSize = 1.0;
-  ignition::math::Vector3d boxPosition(3.0, 0.0, 0.0);
+  gz::math::Vector3d boxPosition(3.0, 0.0, 0.0);
 
   // If ogre2 is not the engine, don't run the test
   if ((_renderEngine.compare("ogre2") != 0))
@@ -406,7 +409,7 @@ void ThermalCameraSensorTest::Images8BitWithBuiltinSDF(
   }
 
   // Setup ign-rendering with an empty scene
-  auto *engine = ignition::rendering::engine(_renderEngine);
+  auto *engine = gz::rendering::engine(_renderEngine);
   if (!engine)
   {
     igndbg << "Engine '" << _renderEngine
@@ -414,14 +417,14 @@ void ThermalCameraSensorTest::Images8BitWithBuiltinSDF(
     return;
   }
 
-  ignition::rendering::ScenePtr scene = engine->CreateScene("scene");
+  gz::rendering::ScenePtr scene = engine->CreateScene("scene");
 
   // Create an scene with a box in it
   scene->SetAmbientLight(0.3, 0.3, 0.3);
-  ignition::rendering::VisualPtr root = scene->RootVisual();
+  gz::rendering::VisualPtr root = scene->RootVisual();
 
   // create box visual
-  ignition::rendering::VisualPtr box = scene->CreateVisual();
+  gz::rendering::VisualPtr box = scene->CreateVisual();
   box->AddGeometry(scene->CreateBox());
   box->SetOrigin(0.0, 0.0, 0.0);
   box->SetLocalPosition(boxPosition);
@@ -434,10 +437,10 @@ void ThermalCameraSensorTest::Images8BitWithBuiltinSDF(
 
   root->AddChild(box);
 
-  ignition::sensors::Manager mgr;
+  gz::sensors::Manager mgr;
 
-  ignition::sensors::ThermalCameraSensor *thermalSensor =
-      mgr.CreateSensor<ignition::sensors::ThermalCameraSensor>(sensorPtr);
+  gz::sensors::ThermalCameraSensor *thermalSensor =
+      mgr.CreateSensor<gz::sensors::ThermalCameraSensor>(sensorPtr);
   ASSERT_NE(thermalSensor, nullptr);
 
   float ambientTemp = 296.0f;
@@ -466,7 +469,7 @@ void ThermalCameraSensorTest::Images8BitWithBuiltinSDF(
   EXPECT_TRUE(infoHelper.WaitForMessage()) << infoHelper;
 
   // subscribe to the thermal camera topic
-  ignition::transport::Node node;
+  gz::transport::Node node;
   node.Subscribe(topic, &OnImage8Bit);
 
   // subscribe to the thermal camera info topic
@@ -540,11 +543,9 @@ void ThermalCameraSensorTest::Images8BitWithBuiltinSDF(
   EXPECT_EQ(9, infoMsg.rectification_matrix().size());
 
   // Check that for a box really close it returns box temperature
-  root->RemoveChild(box);
-  ignition::math::Vector3d boxPositionNear(
+  gz::math::Vector3d boxPositionNear(
       unitBoxSize * 0.5 + near_ * 0.5, 0.0, 0.0);
   box->SetLocalPosition(boxPositionNear);
-  root->AddChild(box);
 
   mgr.RunOnce(std::chrono::steady_clock::duration::zero(), true);
   for (int sleep = 0;
@@ -575,11 +576,9 @@ void ThermalCameraSensorTest::Images8BitWithBuiltinSDF(
   g_mutex.unlock();
 
   // Check that for a box really far it returns ambient temperature
-  root->RemoveChild(box);
   ignition::math::Vector3d boxPositionFar(
       unitBoxSize * 0.5 + far_ * 1.5, 0.0, 0.0);
   box->SetLocalPosition(boxPositionFar);
-  root->AddChild(box);
 
   mgr.RunOnce(std::chrono::steady_clock::duration::zero(), true);
   for (int sleep = 0;
@@ -611,9 +610,13 @@ void ThermalCameraSensorTest::Images8BitWithBuiltinSDF(
   delete [] g_thermalBuffer8Bit;
   g_thermalBuffer8Bit = nullptr;
 
+  // Clean up rendering ptrs
+  box.reset();
+
   // Clean up
+  mgr.Remove(thermalSensor->Id());
   engine->DestroyScene(scene);
-  ignition::rendering::unloadEngine(engine->Name());
+  gz::rendering::unloadEngine(engine->Name());
 }
 
 //////////////////////////////////////////////////
@@ -623,12 +626,12 @@ TEST_P(ThermalCameraSensorTest, Images8BitWithBuiltinSDF)
 }
 
 INSTANTIATE_TEST_CASE_P(ThermalCameraSensor, ThermalCameraSensorTest,
-    RENDER_ENGINE_VALUES, ignition::rendering::PrintToStringParam());
+    RENDER_ENGINE_VALUES, gz::rendering::PrintToStringParam());
 
 //////////////////////////////////////////////////
 int main(int argc, char **argv)
 {
-  ignition::common::Console::SetVerbosity(4);
+  gz::common::Console::SetVerbosity(4);
   ::testing::InitGoogleTest(&argc, argv);
   return RUN_ALL_TESTS();
 }
